import { Box, Flex, Icon, Link, Text, chakra } from "@chakra-ui/react";
import { Swiper, SwiperSlide } from "swiper/react";
import { Navigation } from "swiper/modules";
import "swiper/css";
import "swiper/css/navigation";
import "swiper/css/pagination";
import "swiper/css/scrollbar";
import IconBoxCard from "./icon-box-card";
const SwiperChakra = chakra(Swiper);
import { BsArrowLeftCircle, BsArrowRightCircle } from "react-icons/bs";
import { motion } from "framer-motion";
import Transition from "@/utils/transition-helper";

export default function SwiperBox(){
    const transition = Transition();

    const items = [
      {
        title: "Word to PDF",
        description: "lorem ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, ",
      },
      {
        title: "Word to PDF",
        description: "lorem ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, ",
      },
      {
        title: "Word to PDF",
        description: "lorem ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, ",
      },
      {
        title: "Word to PDF",
        description: "lorem ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, ",
      },
      {
        title: "Word to PDF",
        description: "lorem ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, ",
      },
    ];

    return (
      <Box w="80%" mx="auto" mt={2} as={motion.div} initial="offscreen" whileInView="onscreen" viewport={{ once: true, amount: 0.1 }} variants={transition}>
        <CustomHeader />
        <SwiperChakra
          py={10}
          modules={[Navigation]}
          grabCursor={true}
          navigation={true}
          spaceBetween={16}
          slidesPerView="auto"
          breakpoints={{
            320: { slidesPerView: 1, slidesPerGroup: 1 },
            768: { slidesPerView: 3, slidesPerGroup: 3 },
            1024: { slidesPerView: 4, slidesPerGroup: 4 },
          }}>
          {items.map((item, index) => (
            <SwiperSlide key={index}>
              <IconBoxCard item={item} />
            </SwiperSlide>
          ))}
        </SwiperChakra>
      </Box>
    );
}


const CustomArrow = ({ direction, onClick }: { direction: string; onClick: () => void }) => {
  const boxStyleProps = direction == "prev" ? { left: { base: 0, md: 45, lg: 70 } } : { right: { base: 5, md: 45, lg: 85 } };

  return (
    <Box position="absolute" className={"swiper-custom-button-" + direction} top="35%" transform="translateY(-50%)" cursor="pointer" onClick={onClick} px={2} {...boxStyleProps}>
      <Icon as={direction === "prev" ? BsArrowLeftCircle : BsArrowRightCircle} boxSize={6} color="codGray.500" />
    </Box>
  );
};

const CustomHeader = () => {
  return (
    <Flex justify="space-between" align="center" mb={4}>
      <Box>
        <Text fontSize="lg" fontWeight="bold">
          Featured Items
        </Text>
      </Box>
      <Link href="/view-all" textDecoration="underline" color="codGray.500">
        View All
      </Link>
    </Flex>
  );
};
